==> hoogle-5.0.17.3-107-armv7h.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.17.3
id: hoogle-5.0.17.3-Cc1XlEph4x7m2poeR1W5C
key: hoogle-5.0.17.3-Cc1XlEph4x7m2poeR1W5C
license: BSD-3-Clause
copyright: Neil Mitchell 2004-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
abi: 2e232f7a24f158c9ec2273aeb10558b8
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
import-dirs: /usr/lib/ghc-8.4.3/site-local/hoogle-5.0.17.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/hoogle-5.0.17.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.17.3-Cc1XlEph4x7m2poeR1W5C
include-dirs: /usr/lib/ghc-8.4.3/site-local/hoogle-5.0.17.3/include
includes:
    include.h
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    aeson-1.4.1.0-FRlNztmBJkOGWbKGvmlaJP base-4.11.1.0 binary-0.8.5.1
    bytestring-0.10.8.2 cmdargs-0.10.20-DuSx78jNQymI404wla4i2p
    conduit-1.3.0.3-3atYUnJcrfzHiVZ1ljsUyz
    conduit-extra-1.3.0-Ao8kRXZorHj2LZSVU88NWN
    connection-0.2.8-5iOq4vcUoSB4LCBmEzbnN0 containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5
    extra-1.6.12-DHdLvf94bhcHifO5HapwCI filepath-1.4.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    haskell-src-exts-1.20.3-212SXTWG6Nr7NvhNLFH1Rp
    http-conduit-2.3.2-IeP1yC1Z83J3SHlnSxI17E
    http-types-0.12.2-J5Vk8ZSeZBSHkmLpIqyLht
    js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
    js-jquery-3.3.1-5AJZGDIcfOOHdJQEvwYHms
    mmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO
    process-extras-0.7.4-4RwiW6kVTjg8XKApcgIy4t
    resourcet-1.2.1-90e8KTtIFtW4uIipYnIL1W
    storable-tuple-0.0.3.3-40BRQfXtTlPK75HJy4k7rM
    tar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm template-haskell-2.13.0.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    uniplate-1.6.12-CEZqf1ckZ8W1LfQ2yNgMUt
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    wai-3.2.1.2-40gNQDM5kjaJOQuTlJ5ghk
    wai-logger-2.3.2-H8ICchmLhjsHj5fPSRGJor
    warp-3.2.25-62oJGWXR8SXEm8Ns3jsqYA
    warp-tls-3.2.4.3-7kidbwiTClY7f9VRaG6yGa
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-LgHK7D01MTj1Jd51bZLfR6
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             aeson-1.4.1.0-FRlNztmBJkOGWbKGvmlaJP=5da4d30660c7a0118522c660d6f5af43
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=5eb128502fee539d8b5665038e95d326
             conduit-1.3.0.3-3atYUnJcrfzHiVZ1ljsUyz=636a5a0c86469573aa6778bb72b6971c
             conduit-extra-1.3.0-Ao8kRXZorHj2LZSVU88NWN=7ad1c551e9ebc6ed0d6ad52f692658be
             connection-0.2.8-5iOq4vcUoSB4LCBmEzbnN0=96311fc74e33280c2ae2a728ed041723
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             extra-1.6.12-DHdLvf94bhcHifO5HapwCI=36b397877b0e54ac8d0c415a92aec365
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             haskell-src-exts-1.20.3-212SXTWG6Nr7NvhNLFH1Rp=df17392d21fc8c583a451c456030f555
             http-conduit-2.3.2-IeP1yC1Z83J3SHlnSxI17E=15c9692d3daa01000e44db6ae4be8ef9
             http-types-0.12.2-J5Vk8ZSeZBSHkmLpIqyLht=fbd1db0536204b473a492f230b06f256
             js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ=22192e8eaba4308c5317363c4da3caab
             js-jquery-3.3.1-5AJZGDIcfOOHdJQEvwYHms=d3ef0f45ce429829e7eb9fec57015fc2
             mmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO=caaeec6c17e02ec4d65b4454a8e64ae8
             process-extras-0.7.4-4RwiW6kVTjg8XKApcgIy4t=1646ad5977ae30bea53779b492acc9ba
             resourcet-1.2.1-90e8KTtIFtW4uIipYnIL1W=47912d2f8f0c41e14474b51aa0093f3e
             storable-tuple-0.0.3.3-40BRQfXtTlPK75HJy4k7rM=6156e60913a11c6a98fbfc8ec4c97028
             tar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm=88438dda91eb64a21d8d67f5ddd563b2
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             uniplate-1.6.12-CEZqf1ckZ8W1LfQ2yNgMUt=2b370b8b93631b860e47002fa9510446
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             wai-3.2.1.2-40gNQDM5kjaJOQuTlJ5ghk=eca2af198978641823f297b245875778
             wai-logger-2.3.2-H8ICchmLhjsHj5fPSRGJor=f35437209db89645bd1278a818eb0166
             warp-3.2.25-62oJGWXR8SXEm8Ns3jsqYA=d44d8287b6c1d339a3d53495638f5e96
             warp-tls-3.2.4.3-7kidbwiTClY7f9VRaG6yGa=5940b290ddde032f27667cdd29dffe21
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.2-LgHK7D01MTj1Jd51bZLfR6=330c7805fe7a28a7f81311ba9bcc7e3f
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.17.3-111-armv7h.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.17.3
id: hoogle-5.0.17.3-tKSb0f94g2hjJt6Di2vk
key: hoogle-5.0.17.3-tKSb0f94g2hjJt6Di2vk
license: BSD-3-Clause
copyright: Neil Mitchell 2004-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
abi: e440d1bc7d152dbeac4a1e7e7968b020
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
import-dirs: /usr/lib/ghc-8.4.3/site-local/hoogle-5.0.17.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/hoogle-5.0.17.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.17.3-tKSb0f94g2hjJt6Di2vk
include-dirs: /usr/lib/ghc-8.4.3/site-local/hoogle-5.0.17.3/include
includes:
    include.h
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    aeson-1.4.1.0-HU6cXFeCGhLG5x04YAymhf base-4.11.1.0 binary-0.8.5.1
    bytestring-0.10.8.2 cmdargs-0.10.20-DuSx78jNQymI404wla4i2p
    conduit-1.3.1-D4o2a9oWO4x5dWaRtT4EJt
    conduit-extra-1.3.0-IvSUWo240ze2GEigZ33WNv
    connection-0.2.8-JgdsFAYZbRK7mubDbQZWlt containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5
    extra-1.6.12-DHdLvf94bhcHifO5HapwCI filepath-1.4.2
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    haskell-src-exts-1.20.3-9AUYP4oZqiwGetfJprgKrD
    http-conduit-2.3.2-KkJpwsS02oQGFgMZN2Hf51
    http-types-0.12.2-A8L2J6AAzV9CR4qB3QO3C5
    js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
    js-jquery-3.3.1-Kdf2obXRdql9456Ho9t3G2
    mmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO
    process-extras-0.7.4-41o5wXAnT6feIllwmv8hr
    resourcet-1.2.2-6DzJC8xJzODJ5bfjxaarAo
    storable-tuple-0.0.3.3-Dj9m0x10A8yKoj43vxlEpW
    tar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm template-haskell-2.13.0.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    uniplate-1.6.12-CEZqf1ckZ8W1LfQ2yNgMUt
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    wai-3.2.1.2-8VUlMfZMSx07PKZjROOxWP
    wai-logger-2.3.2-D69KfURbYGEBzjSihhGb9h
    warp-3.2.25-Ns3my97s0QJhY2TWwEpRx
    warp-tls-3.2.4.3-3KMR7FlQUnEG2um60bKswz
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-6VFNTYcbIFUHazSUdvqi9O
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             aeson-1.4.1.0-HU6cXFeCGhLG5x04YAymhf=4a757ff5b48ef239229063edf254f670
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=5eb128502fee539d8b5665038e95d326
             conduit-1.3.1-D4o2a9oWO4x5dWaRtT4EJt=57a4ce950f9daf9d0cdf932d7abba0ef
             conduit-extra-1.3.0-IvSUWo240ze2GEigZ33WNv=19b7d756647f6b712d7a3abb6a1dcde9
             connection-0.2.8-JgdsFAYZbRK7mubDbQZWlt=652695592ef79f9a7d84063259d20d5a
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             extra-1.6.12-DHdLvf94bhcHifO5HapwCI=36b397877b0e54ac8d0c415a92aec365
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             haskell-src-exts-1.20.3-9AUYP4oZqiwGetfJprgKrD=810644ec1507aa9810e91b19577f3c52
             http-conduit-2.3.2-KkJpwsS02oQGFgMZN2Hf51=1b95fd334d59143b211b38a6fa8f1c29
             http-types-0.12.2-A8L2J6AAzV9CR4qB3QO3C5=56212a37e501e1c427ce34403377227d
             js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ=22192e8eaba4308c5317363c4da3caab
             js-jquery-3.3.1-Kdf2obXRdql9456Ho9t3G2=3d4d8e8d0290f554f1b84349648d3cbc
             mmap-0.5.9-EaKbSSGtCoiFENIuyRwCYO=caaeec6c17e02ec4d65b4454a8e64ae8
             process-extras-0.7.4-41o5wXAnT6feIllwmv8hr=04353f5f649b9d1cda50acba0aaed162
             resourcet-1.2.2-6DzJC8xJzODJ5bfjxaarAo=f3a4f434b6add96b232537b442507397
             storable-tuple-0.0.3.3-Dj9m0x10A8yKoj43vxlEpW=649ed9d8293e69cacf3e205f141c0d1b
             tar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm=88438dda91eb64a21d8d67f5ddd563b2
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             uniplate-1.6.12-CEZqf1ckZ8W1LfQ2yNgMUt=2b370b8b93631b860e47002fa9510446
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             wai-3.2.1.2-8VUlMfZMSx07PKZjROOxWP=2e8232f9092b7b7a01776afc0e2fd678
             wai-logger-2.3.2-D69KfURbYGEBzjSihhGb9h=870da8faed68cf9c1612cc2524060927
             warp-3.2.25-Ns3my97s0QJhY2TWwEpRx=7e8aa15aa504eb76e14eddf6c936cf6a
             warp-tls-3.2.4.3-3KMR7FlQUnEG2um60bKswz=5b7d458a1eb3033026461dd02b8a0191
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.2-6VFNTYcbIFUHazSUdvqi9O=fdb582ab967eb93afe5e0be3b51f9140
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
